@@ -7,7 +7,9 @@
 
 use std::path::PathBuf;
 
-use abscissa_core::{Command, Configurable, FrameworkError, Help, Options, Runnable};
+use abscissa_core::{
+    config::Override, Command, Configurable, FrameworkError, Help, Options, Runnable,
+};
 use tracing::info;
 
 use crate::config::Config;
@@ -111,6 +113,20 @@ impl Configurable<Config> for CliCmd {
     /// This can be safely deleted if you don't want to override config
     /// settings from command-line options.
     fn process_config(&self, config: Config) -> Result<Config, FrameworkError> {
-        Ok(config)
+        match self {
+            CliCmd::Tx(cmd) => cmd.override_config(config),
+            // CliCmd::Help(cmd) => cmd.override_config(config),
+            // CliCmd::Keys(cmd) => cmd.override_config(config),
+            // CliCmd::Create(cmd) => cmd.override_config(config),
+            // CliCmd::Update(cmd) => cmd.override_config(config),
+            // CliCmd::Upgrade(cmd) => cmd.override_config(config),
+            // CliCmd::Start(cmd) => cmd.override_config(config),
+            // CliCmd::StartMulti(cmd) => cmd.override_config(config),
+            // CliCmd::Query(cmd) => cmd.override_config(config),
+            // CliCmd::Listen(cmd) => cmd.override_config(config),
+            // CliCmd::Misbehaviour(cmd) => cmd.override_config(config),
+            // CliCmd::Version(cmd) => cmd.override_config(config),
+            _ => Ok(config),
+        }
     }
 }
