@@ -24,6 +24,12 @@ pub struct KeyRestoreCmd {
         default_expr = "CoinType::ATOM"
     )]
     coin_type: CoinType,
+
+    #[options(
+        short = "n",
+        help = "name of the key (defaults to the `key_name` defined in the config)"
+    )]
+    name: Option<String>,
 }
 
 #[derive(Clone, Debug)]
@@ -31,6 +37,7 @@ pub struct KeysRestoreOptions {
     pub mnemonic: String,
     pub config: ChainConfig,
     pub coin_type: CoinType,
+    pub key_name: String,
 }
 
 impl KeyRestoreCmd {
@@ -43,6 +50,10 @@ impl KeyRestoreCmd {
             mnemonic: self.mnemonic.clone(),
             config: chain_config.clone(),
             coin_type: self.coin_type,
+            key_name: self
+                .name
+                .clone()
+                .unwrap_or_else(|| chain_config.key_name.clone()),
         })
     }
 }
@@ -56,14 +67,13 @@ impl Runnable for KeyRestoreCmd {
             Ok(result) => result,
         };
 
-        let key_name = opts.config.key_name.clone();
         let chain_id = opts.config.id.clone();
-        let key = restore_key(&opts.mnemonic, opts.coin_type, opts.config);
+        let key = restore_key(&opts.mnemonic, &opts.key_name, opts.coin_type, opts.config);
 
         match key {
             Ok(key) => Output::success_msg(format!(
                 "Restored key '{}' ({}) on chain {}",
-                key_name, key.account, chain_id
+                opts.key_name, key.account, chain_id
             ))
             .exit(),
             Err(e) => Output::error(format!("{}", e)).exit(),
@@ -73,12 +83,13 @@ impl Runnable for KeyRestoreCmd {
 
 pub fn restore_key(
     mnemonic: &str,
+    key_name: &str,
     coin_type: CoinType,
     config: ChainConfig,
 ) -> Result<KeyEntry, BoxError> {
-    let mut keyring = KeyRing::new(Store::Test, config)?;
+    let mut keyring = KeyRing::new(Store::Test, &config.account_prefix, &config.id)?;
     let key_entry = keyring.key_from_mnemonic(mnemonic, coin_type)?;
-    keyring.add_key(key_entry.clone())?;
 
+    keyring.add_key(&key_name, key_entry.clone())?;
     Ok(key_entry)
 }
